animated_text_kit library

Animated Text Kit is a library of some cool and awesome text animations.

Classes

AnimatedText
Abstract base class for text animations.
AnimatedTextController
A controller for managing the state of an animated text sequence.
AnimatedTextKit
Base class for Animated Text widgets.
AnimatedTextKitState
BounceAnimatedText
Animated Text that displays a Text element with a bouncing effect.
BounceAnimatedTextKit
Animation that displays text elements with a bouncing effect, one at a time.
ColorizeAnimatedText
Animated Text that shows text shimmering between colors.
ColorizeAnimatedTextKit
Animation that displays text elements, shimmering transition between colors.
FadeAnimatedText
Animated Text that displays a Text element, fading it in and then out.
FadeAnimatedTextKit
Animation that displays text elements, fading them in and then out.
FlickerAnimatedText
Animated Text that displays a Text element, as a flickering glow text.
FlickerAnimatedTextKit
RotateAnimatedText
Animated Text that rotates a Text in and then out.
RotateAnimatedTextKit
Animation that displays text elements, rotating them in one at a time.
ScaleAnimatedText
Animated Text that displays a Text element, scaling them up and then out.
ScaleAnimatedTextKit
Animation that displays text elements, scaling them up and then out, one at a time.
ScrambleAnimatedText
ScrambledChar
TextLiquidFill
Animation that displays a text element, coloring it to look like sloshing water is filling it up.
TextLiquidFillState
TyperAnimatedText
Animated Text that displays a Text element as if it is being typed one character at a time.
TyperAnimatedTextKit
Animation that displays text elements, as if they are being typed one character at a time.
TypewriterAnimatedText
Animated Text that displays a Text element as if it is being typed one character at a time. Similar to TyperAnimatedText, but shows a cursor.
TypewriterAnimatedTextKit
Animation that displays text elements, as if they are being typed one character at a time. Similar to TyperAnimatedTextKit, but shows a cursor.
WavyAnimatedText
Animated Text that displays a Text element with each character popping like a stadium wave.
WavyAnimatedTextKit
Animation that displays text elements, with each text animated with its characters popping like a stadium wave.

Enums

AnimatedTextState
The various states that the animated text can be in: